@@ -12,7 +12,7 @@
 #' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
 #' @export
 #'
-#' @examplesIf broom.helpers::.assert_package("car", pkg_search = "gtsummary", boolean = TRUE)
+#' @examplesIf identical(Sys.getenv("IN_PKGDOWN"), "true") && broom.helpers::.assert_package("car", pkg_search = "gtsummary", boolean = TRUE)
 #' \donttest{
 #' # Example 1 ----------------------------------
 #' add_vif_ex1 <-
@@ -29,10 +29,14 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{add_vif_ex1.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "add_vif_ex1.png", width = "45")`
+#' }}
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{add_vif_ex2.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "add_vif_ex2.png", width = "45")`
+#' }}
 #'
 add_vif <- function(x, statistic = NULL, estimate_fun = NULL) {
   updated_call_list <- c(x$call_list, list(add_vif = match.call()))
@@ -77,7 +81,7 @@ add_vif <- function(x, statistic = NULL, estimate_fun = NULL) {
   for (s in statistic) {
     x <- x %>%
       modify_table_styling(
-        s,
+        all_of(s),
         label = switch(s,
           "VIF" = "**VIF**",
           "GVIF" = "**GVIF**",
@@ -135,8 +139,8 @@ add_vif <- function(x, statistic = NULL, estimate_fun = NULL) {
       tibble::rownames_to_column(var = "variable") %>%
       tibble::as_tibble() %>%
       dplyr::rename(
-        aGVIF = .data$`GVIF^(1/(2*Df))`,
-        df = .data$Df
+        aGVIF = "GVIF^(1/(2*Df))",
+        df = "Df"
       )
   }
 
