@@ -19,12 +19,14 @@
 #' @return A {huxtable} object
 #' @family gtsummary output types
 #' @author David Hugh-Jones, Daniel D. Sjoberg
-#' @examplesIf broom.helpers::.assert_package("huxtable", pkg_search = "gtsummary", boolean = TRUE)
+#' @examplesIf identical(Sys.getenv("IN_PKGDOWN"), "true") && broom.helpers::.assert_package("huxtable", pkg_search = "gtsummary", boolean = TRUE)
+#' \donttest{
 #' trial %>%
 #'   dplyr::select(trt, age, grade) %>%
 #'   tbl_summary(by = trt) %>%
 #'   add_p() %>%
 #'   as_hux_table()
+#' }
 NULL
 
 #' @export
@@ -87,7 +89,7 @@ as_hux_xlsx <- function(x, file, include = everything(), bold_header_rows = TRUE
 
   # save list of expressions to run --------------------------------------------
   huxtable_calls <-
-    as_hux_table(x = x, include = include, return_calls = TRUE) %>%
+    as_hux_table(x = x, include = {{ include }}, return_calls = TRUE) %>%
     purrr::list_modify(set_left_padding = NULL, set_left_padding2 = NULL)
 
   # construct calls to manually indent the columns -----------------------------
@@ -125,7 +127,7 @@ as_hux_xlsx <- function(x, file, include = everything(), bold_header_rows = TRUE
   }
 
   # run hux commands and export to excel ---------------------------------------
-  .eval_list_of_exprs(huxtable_calls[include]) %>%
+  .eval_list_of_exprs(huxtable_calls) %>%
     huxtable::quick_xlsx(file = file, open = FALSE)
 }
 
@@ -158,7 +160,7 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   # padding --------------------------------------------------------------------
   df_padding <-
     x$table_styling$header %>%
-    select(.data$id, .data$column) %>%
+    select("id", "column") %>%
     inner_join(
       x$table_styling$text_format %>%
         filter(.data$format_type == "indent"),
@@ -178,7 +180,7 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   # padding2 -------------------------------------------------------------------
   df_padding2 <-
     x$table_styling$header %>%
-    select(.data$id, .data$column) %>%
+    select("id", "column") %>%
     inner_join(
       x$table_styling$text_format %>%
         filter(.data$format_type == "indent2"),
@@ -198,7 +200,7 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   # footnote -------------------------------------------------------------------
   vct_footnote <-
     .number_footnotes(x) %>%
-    pull(.data$footnote) %>%
+    pull("footnote") %>%
     unique()
   border <- rep_len(0, length(vct_footnote))
   border[1] <- 0.8
@@ -231,10 +233,10 @@ table_styling_to_huxtable_calls <- function(x, ...) {
     x$table_styling$text_format %>%
     filter(.data$format_type == "bold") %>%
     inner_join(x$table_styling$header %>%
-                 select(.data$column, column_id = .data$id),
+                 select("column", column_id = "id"),
                by = "column"
     ) %>%
-    select(.data$format_type, .data$row_numbers, .data$column_id)
+    select("format_type", "row_numbers", "column_id")
 
   huxtable_calls[["set_bold"]] <-
     map(
@@ -251,10 +253,10 @@ table_styling_to_huxtable_calls <- function(x, ...) {
     x$table_styling$text_format %>%
     filter(.data$format_type == "italic") %>%
     inner_join(x$table_styling$header %>%
-                 select(.data$column, column_id = .data$id),
+                 select("column", column_id = "id"),
                by = "column"
     ) %>%
-    select(.data$format_type, .data$row_numbers, .data$column_id)
+    select("format_type", "row_numbers", "column_id")
 
   huxtable_calls[["set_italic"]] <-
     map(
@@ -282,11 +284,11 @@ table_styling_to_huxtable_calls <- function(x, ...) {
     x$table_styling$fmt_missing %>%
     inner_join(
       x$table_styling$header %>%
-        select(.data$column, column_id = .data$id),
+        select("column", column_id = "id"),
       by = "column"
     ) %>%
-    select(.data$symbol, .data$row_numbers, .data$column_id) %>%
-    nest(location_ids = .data$column_id) %>%
+    select("symbol", "row_numbers", "column_id") %>%
+    nest(location_ids = "column_id") %>%
     mutate(
       column_id = map(.data$location_ids, ~ pluck(.x, "column_id") %>% unique())
     )
@@ -308,7 +310,7 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   col_labels <-
     x$table_styling$header %>%
     filter(.data$hide == FALSE) %>%
-    select(.data$column, .data$label) %>%
+    select("column", "label") %>%
     tibble::deframe()
 
   huxtable_calls[["insert_row"]] <- list()
@@ -367,7 +369,7 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   df_align <-
     x$table_styling$header %>%
     filter(.data$hide == FALSE) %>%
-    select(.data$id, .data$align) %>%
+    select("id", "align") %>%
     group_by(.data$align) %>%
     nest() %>%
     ungroup()
