@@ -57,7 +57,7 @@
 #' @name custom_tidiers
 #' @rdname custom_tidiers
 #' @export
-#' @examplesIf broom.helpers::.assert_package("effectsize", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("parameters", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("mice", pkg_search = "gtsummary", boolean = TRUE)
+#' @examplesIf identical(Sys.getenv("IN_PKGDOWN"), "true") && broom.helpers::.assert_package("effectsize", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("parameters", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("mice", pkg_search = "gtsummary", boolean = TRUE)
 #' \donttest{
 #' # Example 1 ----------------------------------
 #' mod <- lm(age ~ marker + grade, trial)
@@ -87,15 +87,21 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{tidy_standardize_ex1.png}{options: width=65\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tidy_standardize_ex1.png", width = "65")`
+#' }}
 #'
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{tidy_standardize_ex2.png}{options: width=47\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tidy_standardize_ex2.png", width = "47")`
+#' }}
 #'
 #' \if{html}{Example 3}
 #'
-#' \if{html}{\figure{pool_and_tidy_mice_ex3.png}{options: width=47\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "pool_and_tidy_mice_ex3.png", width = "47")`
+#' }}
 
 tidy_standardize <- function(x, exponentiate = FALSE,
                              conf.level = 0.95,
@@ -117,13 +123,13 @@ tidy_standardize <- function(x, exponentiate = FALSE,
   tidy <-
     as_tibble(std_coef) %>%
     select(
-      term = .data$Parameter, estimate = .data$Std_Coefficient,
-      conf.low = .data$CI_low, conf.high = .data$CI_high
+      term = "Parameter", estimate = "Std_Coefficient",
+      conf.low = "CI_low", conf.high = "CI_high"
     )
 
   # exponentiate, if requested
   if (exponentiate) {
-    tidy <- mutate_at(tidy, vars(.data$estimate, .data$conf.low, .data$conf.high), exp)
+    tidy <- mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested
@@ -153,13 +159,13 @@ tidy_bootstrap <- function(x, exponentiate = FALSE,
   tidy <-
     as_tibble(boot_coef) %>%
     select(
-      term = .data$Parameter, estimate = .data$Coefficient,
-      conf.low = .data$CI_low, conf.high = .data$CI_high, p.value = .data$p
+      term = "Parameter", estimate = "Coefficient",
+      conf.low = "CI_low", conf.high = "CI_high", p.value = "p"
     )
 
   # exponentiate, if requested
   if (exponentiate) {
-    tidy <- mutate_at(tidy, vars(.data$estimate, .data$conf.low, .data$conf.high), exp)
+    tidy <- mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested
@@ -208,7 +214,7 @@ tidy_robust <- function(x,
   # exponentiate, if requested -------------------------------------------------
   if (exponentiate) {
     tidy <-
-      mutate_at(tidy, vars(.data$estimate, .data$conf.low, .data$conf.high), exp)
+      mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested --------------------------------------------
@@ -259,7 +265,7 @@ tidy_gam <- function(x, conf.int = FALSE, exponentiate = FALSE, conf.level = 0.9
       broom::tidy(x, parametric = FALSE, ...) %>%
         dplyr::mutate(parametric = FALSE)
     ) %>%
-    dplyr::relocate(.data$parametric, .after = dplyr::last_col())
+    dplyr::relocate("parametric", .after = dplyr::last_col())
 }
 
 #' @rdname custom_tidiers
@@ -275,10 +281,10 @@ tidy_wald_test <- function(x, tidy_fun = NULL, ...) {
     tidy_fun = tidy_fun
   ) %>%
     broom.helpers::tidy_identify_variables() %>%
-    dplyr::select(term = .data$variable, model_terms = .data$term) %>%
+    dplyr::select(term = "variable", model_terms = "term") %>%
     dplyr::mutate(term_id = dplyr::row_number()) %>%
     # reduce to one line per variable in model
-    tidyr::nest(data = -.data$term) %>%
+    tidyr::nest(data = -"term") %>%
     dplyr::rowwise() %>%
     # calculate Wald test
     dplyr::mutate(
@@ -296,5 +302,5 @@ tidy_wald_test <- function(x, tidy_fun = NULL, ...) {
       p.value = .data$wald_test$result$chi2 %>% purrr::pluck("P"),
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::select(.data$term, .data$df, .data$statistic, .data$p.value)
+    dplyr::select("term", "df", "statistic", "p.value")
 }
