@@ -91,15 +91,21 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{modify_ex1.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "modify_ex1.png", width = "45")`
+#' }}
 #'
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{modify_ex2.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "modify_ex2.png", width = "45")`
+#' }}
 #'
 #' \if{html}{Example 3}
 #'
-#' \if{html}{\figure{modify_ex3.png}{options: width=35\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "modify_ex3.png", width = "35")`
+#' }}
 NULL
 
 #' @name modify
@@ -114,20 +120,9 @@ modify_header <- function(x, update = NULL, ..., text_interpret = c("md", "html"
 
   # converting update and dots args to a tidyselect list -----------------------
   if (!is.null(stat_by)) {
-    lifecycle::deprecate_warn(
+    lifecycle::deprecate_stop(
       "1.3.6", "gtsummary::modify_header(stat_by=)",
       details = glue("Use `all_stat_cols(FALSE) ~ {stat_by}` instead."))
-
-    lst_stat_by <-
-      list(rlang::new_formula(lhs = expr(all_stat_cols(FALSE)), rhs = stat_by))
-
-    # adding stat_by code to `update=`
-    if (is.null(update) || rlang::is_list(update)) {
-      update <- c(lst_stat_by, update)
-    }
-    else if (!rlang::is_list(update)) {
-      update <- c(lst_stat_by, list(update))
-    }
   }
   update <- .combine_update_and_dots(x, update, ...)
 
@@ -277,13 +272,13 @@ show_header_names <- function(x = NULL, include_example = TRUE, quiet = NULL) {
   df_cols <-
     x$table_styling$header %>%
     filter(.data$hide == FALSE) %>%
-    select(.data$column, .data$label)
+    select("column", "label")
 
   if (identical(quiet, FALSE) && isTRUE(include_example)) {
     cat("\n")
     cli_alert_info("As a usage guide, the code below re-creates the current column headers.")
     block <- mutate(df_cols, formula = glue("  {column} = {shQuote(label)}")) %>%
-      pull(.data$formula) %>%
+      pull("formula") %>%
       paste0("", collapse = ",\n") %>%
       {
         glue("modify_header(\n{.}\n)")
@@ -323,7 +318,7 @@ show_header_names <- function(x = NULL, include_example = TRUE, quiet = NULL) {
     data = x$table_body,
     var_info =
       x$table_styling$header %>%
-      select(.data$column, .data$hide, starts_with("modify_selector_")) %>%
+      select("column", "hide", starts_with("modify_selector_")) %>%
       dplyr::rename_with(
         .fn = ~stringr::str_remove(., pattern = fixed("modify_selector_")),
         starts_with("modify_selector_")
@@ -337,7 +332,7 @@ show_header_names <- function(x = NULL, include_example = TRUE, quiet = NULL) {
 .eval_with_glue <- function(x, update) {
   df_header <-
     x$table_styling$header %>%
-    select(.data$column, starts_with("modify_stat_")) %>%
+    select("column", starts_with("modify_stat_")) %>%
     dplyr::rename_with(~stringr::str_replace(., fixed("modify_stat_"), fixed("")))
 
   imap(
