@@ -5,6 +5,8 @@
 #' @param x gtsummary object
 #' @param variables variables to to remove rows from. Default is `everything()`
 #' @param type type of row to remove. Must be one of
+#' @param level_value When `type='level'` you can specify the *character* value of the level to remove.
+#' When `NULL` all levels are removed.
 #' `c("header", "reference", "missing")`
 #' @export
 #' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
@@ -23,14 +25,24 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{remove_row_type_ex1.png}{options: width=60\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "remove_row_type_ex1.png", width = "60")`
+#' }}
 remove_row_type <- function(x, variables = everything(),
-                            type = c("header", "reference", "missing")) {
+                            type = c("header", "reference", "missing", "level", "all"),
+                            level_value = NULL) {
   updated_call_list <- c(x$call_list, list(remove_row_type = match.call()))
   # check inputs ---------------------------------------------------------------
   .assert_class(x, "gtsummary")
   type <- match.arg(type)
 
+  if (!is.null(level_value) && type != "level") {
+    cli::cli_inform("Argument {.code level_value} ignored when {.code type != 'level'}")
+  }
+  if (!is.null(level_value) && !is.character(level_value)) {
+    cli::cli_abort("The {.code level_value} argument must be class {.cls character}")
+  }
+
   # convert variables input to character variable names ------------------------
   variables <-
     .select_to_varnames(
@@ -64,6 +76,23 @@ remove_row_type <- function(x, variables = everything(),
       variables = "row_type",
       expr = expr(.data$row_type == "missing")
     )
+  } else if (type == "level") {
+    if (!is.null(level_value)) {
+      lst_expr <- list(
+        variables = c("row_type", "label"),
+        expr = expr(.data$row_type == "level" & .data$label %in% level_value)
+        )
+    } else {
+      lst_expr <- list(
+        variables = "row_type",
+        expr = expr(.data$row_type == "level")
+        )
+    }
+  } else if (type == "all") {
+    lst_expr <- list(
+      variables = "variable",
+      expr = expr(!is.na(.data$variable))
+    )
   }
 
   if (!all(lst_expr[["variables"]] %in% names(x$table_body))) {
