@@ -10,7 +10,7 @@
 #' @export
 #' @return A character vector of styled percentages
 #' @family style tools
-#' @seealso See Table Gallery \href{http://www.danieldsjoberg.com/gtsummary/articles/gallery.html}{vignette} for example
+#' @seealso See Table Gallery \href{https://www.danieldsjoberg.com/gtsummary/articles/gallery.html}{vignette} for example
 #' @author Daniel D. Sjoberg
 #' @examples
 #' percent_vals <- c(-1, 0, 0.0001, 0.005, 0.01, 0.10, 0.45356, 0.99, 1.45)
@@ -29,5 +29,6 @@ style_percent <- function(x, symbol = FALSE, digits = 0, big.mark = NULL, decima
 
   # adding percent symbol if requested
   if (symbol == TRUE) y <- ifelse(!is.na(y), paste0(y, "%"), y)
+  attributes(y) <- attributes(x)
   return(y)
 }
