@@ -24,8 +24,8 @@
 #'   style_ratio()
 style_ratio <- function(x, digits = 2, big.mark = NULL, decimal.mark = NULL, ...) {
   ifelse(
-    round(abs(x), digits = digits - 1) < 1,
+    round2(abs(x), digits = digits) < 1,
     style_sigfig(x, digits = digits, big.mark = big.mark, decimal.mark = decimal.mark, ...),
-    style_sigfig(x, digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, ...)
+    style_sigfig(pmax(1, x), digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, ...)
   )
 }
