@@ -180,19 +180,27 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{tbl_summary_ex1.png}{options: width=31\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_summary_ex1.png", width = "31")`
+#' }}
 #'
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{tbl_summary_ex2.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_summary_ex2.png", width = "45")`
+#' }}
 #'
 #' \if{html}{Example 3}
 #'
-#' \if{html}{\figure{tbl_summary_ex3.png}{options: width=45\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_summary_ex3.png", width = "45")`
+#' }}
 #'
 #' \if{html}{Example 4}
 #'
-#' \if{html}{\figure{tbl_summary_ex4.png}{options: width=31\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "tbl_summary_ex4.png", width = "31")`
+#' }}
 
 tbl_summary <- function(data, by = NULL, label = NULL, statistic = NULL,
                         digits = NULL, type = NULL, value = NULL,
@@ -287,9 +295,9 @@ tbl_summary <- function(data, by = NULL, label = NULL, statistic = NULL,
         }
       )
     ) %>%
-    select(var_type = .data$summary_type, .data$var_label, .data$tbl_stats) %>%
-    unnest(.data$tbl_stats) %>%
-    select(.data$variable, .data$var_type, .data$var_label, everything())
+    select(var_type = "summary_type", "var_label", "tbl_stats") %>%
+    unnest("tbl_stats") %>%
+    select("variable", "var_type", "var_label", everything())
 
   # table of column headers ----------------------------------------------------
   x <-
@@ -310,10 +318,10 @@ tbl_summary <- function(data, by = NULL, label = NULL, statistic = NULL,
       x$table_styling$header %>%
       dplyr::left_join(
         x$df_by %>%
-          select(column = .data$by_col,
-                 modify_stat_n = .data$n,
-                 modify_stat_p = .data$p,
-                 modify_stat_level = .data$by_chr),
+          select(column = "by_col",
+                 modify_stat_n = "n",
+                 modify_stat_p = "p",
+                 modify_stat_level = "by_chr"),
         by = "column"
       )
   }
