@@ -46,10 +46,17 @@
       text_interpret = character(), footnote = character()
     )
   x$table_styling$text_format <-
-    tibble(
-      column = "label", rows = list(rlang::expr(.data$row_type %in% c("level", "missing"))),
-      format_type = "indent", undo_text_format = FALSE
+    purrr::when(
+      all(c("label", "row_type") %in% x$table_styling$header$column),
+      isTRUE(.) ~
+        tibble(column = "label",
+               rows = list(rlang::expr(.data$row_type %in% c("level", "missing"))),
+               format_type = "indent", undo_text_format = FALSE),
+      isFALSE(.) ~
+        tibble(column = character(), rows = list(),
+               format_type = character(), undo_text_format = logical())
     )
+
   x$table_styling$fmt_missing <-
     tibble(column = character(), rows = list(), symbol = character())
   x$table_styling$fmt_fun <-
@@ -97,11 +104,24 @@
       interpret_spanning_header = "gt::md",
       spanning_header = NA_character_
     ) %>%
-    dplyr::rows_update(
-      x$table_styling$header,
-      by = "column"
-    )
+    .rows_update_table_styling_header(x$table_styling$header)
 
   # return x -------------------------------------------------------------------
   x
 }
+
+.rows_update_table_styling_header <- function(x, y) {
+  common_columns <-intersect(names(x), names(y))
+
+  x %>%
+    # updating rows in header
+    dplyr::rows_update(
+      y %>% select(all_of(common_columns)),
+      by = "column"
+    ) %>%
+    # re-adding the columns not in the original header table
+    dplyr::left_join(
+      y %>% select(-all_of(setdiff(common_columns, "column"))),
+      by = "column"
+    )
+}
