@@ -25,12 +25,14 @@ tbl_summary_ex$table_body
 tibble::tribble(
   ~Column, ~Description,
   "column", "Column name from `.$table_body`",
-  "hide", "Logical indicating whether the column is hidden in the output",
+  "hide", "Logical indicating whether the column is hidden in the output. This column is also scoped in `modify_header()` (and friends) to be used in a selecting environment",
   "align", "Specifies the alignment/justification of the column, e.g. 'center' or 'left'",
   "label", "Label that will be displayed (if column is displayed in output)",
   "interpret_label", "the {gt} function that is used to interpret the column label, `gt::md()` or `gt::html()`",
   "spanning_header", "Includes text printed above columns as spanning headers.",
-  "interpret_spanning_header", "the {gt} function that is used to interpret the column spanning headers, `gt::md()` or `gt::html()`"
+  "interpret_spanning_header", "the {gt} function that is used to interpret the column spanning headers, `gt::md()` or `gt::html()`",
+  "modify_stat_{*}", "any column beginning with `modify_stat_` is a statistic available to report in `modify_header()` (and others)",
+  "modify_selector_{*}", "any column beginning with `modify_selector_` is a column that is scoped in `modify_header()` (and friends) to be used in a selecting environment"
 ) %>%
   gt::gt() %>%
   gt::fmt_markdown(columns = everything()) %>%
