@@ -24,10 +24,12 @@ test_that("tbl_uvregression", {
 })
 
 test_that("tbl_survfit", {
+  skip_if_not(broom.helpers::.assert_package("survival", pkg_search = "gtsummary", boolean = TRUE))
   library(survival)
   fit1 <- survfit(Surv(ttdeath, death) ~ trt, trial)
 
   expect_error(tbl_survfit(fit1, times = c(12, 24), label_header = "**{time} Months**") %>% as_gt(), NA)
+  expect_error(as_gt(fit1))
 })
 
 test_that("indent2", {
