@@ -1,3 +1,5 @@
+
+
 skip_on_cran()
 
 tbl <- trial %>%
@@ -5,6 +7,20 @@ tbl <- trial %>%
   add_p() %>%
   add_q()
 
+
+tbl_cross_ex <- trial %>%
+  tbl_cross(row = trt, col = response)
+
+tbl_uv_ex1 <-
+  tbl_uvregression(
+    trial[c("response", "age", "grade")],
+    method = glm,
+    y = response,
+    method.args = list(family = binomial),
+    exponentiate = TRUE
+  )
+
+
 test_that("tab_style: bold and italicize", {
   expect_error(
     tbl %>%
@@ -16,6 +32,25 @@ test_that("tab_style: bold and italicize", {
       bold_p(q = TRUE, t = 0.2),
     NA
   )
+
+  expect_error(
+    tbl_cross_ex %>%
+      bold_labels() %>%
+      bold_levels() %>%
+      italicize_labels() %>%
+      italicize_levels(),
+    NA
+  )
+
+  expect_error(
+    tbl_uv_ex1 %>%
+      bold_labels() %>%
+      bold_levels() %>%
+      italicize_labels() %>%
+      italicize_levels(),
+    NA
+  )
+
   expect_warning(
     tbl %>%
       bold_labels() %>%
@@ -51,3 +86,8 @@ test_that("error when non-gtsummary object passed", {
     NULL
   )
 })
+
+
+
+
+
