@@ -23,8 +23,9 @@
 skip_on_cran()
 # vetted models checks take a long time--only perform on CI checks
 skip_if(!isTRUE(as.logical(Sys.getenv("CI"))))
-skip_if_not(requireNamespace("car"))
-skip_if_not(requireNamespace("lme4"))
+skip_if_not(broom.helpers::.assert_package("car", pkg_search = "gtsummary", boolean = TRUE))
+skip_if_not(broom.helpers::.assert_package("lme4", pkg_search = "gtsummary", boolean = TRUE))
+skip_if_not(broom.helpers::.assert_package("survival", pkg_search = "gtsummary", boolean = TRUE))
 library(dplyr)
 
 # glmer() --------------------------------------------------------------------
